#[non_exhaustive]
pub enum PgAdvisoryLockKey {
    BigInt(i64),
    IntPair(i32i32),
}
A key type natively used by Postgres advisory locks.

Currently, Postgres advisory locks have two different key spaces: one keyed by a single 64-bit integer, and one keyed by a pair of two 32-bit integers. The Postgres docs specify that these key spaces “do not overlap”:

https://www.postgresql.org/docs/current/functions-admin.html#FUNCTIONS-ADVISORY-LOCKS

The documentation for the pg_locks system view explains further how advisory locks are treated in Postgres:

https://www.postgresql.org/docs/current/view-pg-locks.html

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.

BigInt(i64)

The keyspace designated by a single 64-bit integer.

When PgAdvisoryLock is constructed with ::new(), this is the keyspace used.

IntPair(i32i32)

The keyspace designated by two 32-bit integers.

Implementations

Converts Self::Bigint(bigint) to Some(bigint) and all else to None.